==> fastmicro-0.1.3.tar.gz: fastmicro-0.1.3/fastmicro/service.py <==
import asyncio
import atexit
from functools import partial
import logging
import signal
from typing import Any, Awaitable, Callable, List, Optional
import uvloop

from fastmicro.entrypoint import AT, BT, Entrypoint
from fastmicro.messaging import MessagingABC
from fastmicro.topic import Topic

logger = logging.getLogger(__name__)

signal.signal(signal.SIGINT, signal.SIG_DFL)
uvloop.install()


class Service:
    def __init__(
        self,
        name: str,
        messaging: MessagingABC,
        loop: Optional[asyncio.AbstractEventLoop] = None,
    ) -> None:
        if loop:
            self.loop = loop
        else:
            self.loop = asyncio.get_event_loop()

        self.name = name
        self.messaging = messaging
        self.entrypoints: List[Entrypoint] = list()

    def entrypoint(
        self, topic: Topic[AT], reply_topic: Topic[BT], **kwargs: Any
    ) -> Callable[[Callable[[AT], Awaitable[BT]]], Entrypoint[AT, BT]]:
        def _entrypoint(callback: Callable[[AT], Awaitable[BT]]) -> Entrypoint[AT, BT]:
            entrypoint = Entrypoint(
                self.name + "_" + callback.__name__,
                self.messaging,
                callback,
                topic,
                reply_topic,
                loop=self.loop,
                **kwargs,
            )
            self.entrypoints.append(entrypoint)
            return entrypoint

        return _entrypoint

    async def start(self) -> None:
        await self.messaging.connect()

        tasks = [entrypoint.start() for entrypoint in self.entrypoints]
        await asyncio.gather(*tasks)

    def run(self) -> None:
        self.loop.run_until_complete(self.start())
        atexit.register(partial(self.loop.run_until_complete, self.stop))
        self.loop.run_forever()

    async def stop(self) -> None:
        tasks = [entrypoint.stop() for entrypoint in self.entrypoints]
        await asyncio.gather(*tasks)

        await self.messaging.cleanup()

==> fastmicro-0.2.1.tar.gz: fastmicro-0.2.1/fastmicro/service.py <==
import asyncio
import atexit
from functools import partial
import signal
from typing import Any, Awaitable, Callable, List, Optional
import uvloop

from fastmicro.entrypoint import AT, BT, Entrypoint
from fastmicro.messaging import MessagingABC, TopicABC

signal.signal(signal.SIGINT, signal.SIG_DFL)
uvloop.install()


class Service:
    def __init__(
        self,
        name: str,
        messaging: MessagingABC,
        loop: Optional[asyncio.AbstractEventLoop] = None,
    ) -> None:
        if loop:
            self.loop = loop
        else:
            self.loop = asyncio.get_event_loop()

        self.name = name
        self.messaging = messaging
        self.start_callbacks: List[Callable[[], Awaitable[None]]] = list()
        self.stop_callbacks: List[Callable[[], Awaitable[None]]] = list()

    def entrypoint(
        self, topic: TopicABC[AT], reply_topic: TopicABC[BT], **kwargs: Any
    ) -> Callable[[Callable[[AT], Awaitable[BT]]], Entrypoint[AT, BT]]:
        def _entrypoint(callback: Callable[[AT], Awaitable[BT]]) -> Entrypoint[AT, BT]:
            entrypoint = Entrypoint[AT, BT](
                self.name + "_" + callback.__name__,
                callback,
                topic,
                reply_topic,
                loop=self.loop,
                **kwargs,
            )
            self.start_callbacks.append(entrypoint.start)
            self.stop_callbacks.append(entrypoint.stop)
            return entrypoint

        return _entrypoint

    async def start(self) -> None:
        await self.messaging.connect()

        tasks = [start_callback() for start_callback in self.start_callbacks]
        await asyncio.gather(*tasks)

    def run(self) -> None:
        self.loop.run_until_complete(self.start())
        atexit.register(partial(self.loop.run_until_complete, self.stop))
        self.loop.run_forever()

    async def stop(self) -> None:
        tasks = [stop_callback() for stop_callback in self.stop_callbacks]
        await asyncio.gather(*tasks)

        await self.messaging.cleanup()
